# Academia TTS

This package provides tools to convert PPTX slide notes to audio files and embed them into the slides.

## Install from pip
To install the package using pip, run:

```bash
pip install academia-tts
```


## Build from scratch

To build the package from scratch, run:

```bash
git clone https://github.com/l1997i/academia_tts
pip install .
```
